pub struct LineIndex { /* private fields */ }Expand description
Precomputed line-start offset table for O(log n) line/column ↔ byte offset conversion.
Implementations
Sourceimpl LineIndex
impl LineIndex
pub fn new(text: &str) -> Self
pub fn line_count(&self) -> u32
pub fn text_len(&self) -> u32
Sourcepub fn offset_to_position(
&self,
text: &str,
offset: usize,
) -> Result<Position, TextViewError>
pub fn offset_to_position( &self, text: &str, offset: usize, ) -> Result<Position, TextViewError>
Convert a byte offset to a 0-based line/column position.
Sourcepub fn position_to_offset(
&self,
text: &str,
position: Position,
) -> Result<usize, TextViewError>
pub fn position_to_offset( &self, text: &str, position: Position, ) -> Result<usize, TextViewError>
Convert a 0-based line/column position to a byte offset.
Sourcepub fn line_range(&self, line: u32) -> Result<TextRange, TextViewError>
pub fn line_range(&self, line: u32) -> Result<TextRange, TextViewError>
Return the byte range of a line excluding its trailing newline.
Sourcepub fn line_range_with_newline(
&self,
line: u32,
) -> Result<TextRange, TextViewError>
pub fn line_range_with_newline( &self, line: u32, ) -> Result<TextRange, TextViewError>
Return the byte range of a line including its trailing newline.
Sourcepub fn line_of_offset(&self, offset: usize) -> Result<u32, TextViewError>
pub fn line_of_offset(&self, offset: usize) -> Result<u32, TextViewError>
Return the 0-based line number that contains the given byte offset.